@@ -3,6 +3,8 @@ Global constants.
 
 Please keep synced with
   scripts/treebank_to_shorthand.sh
+
+These language codes mirror UD language codes when possible
 """
 
 lcode2lang = {
@@ -18,7 +20,9 @@ lcode2lang = {
     "aii": "Assyrian",
     "bm": "Bambara",
     "eu": "Basque",
+    "bej": "Beja",
     "be": "Belarusian",
+    "bn": "Bengali",
     "bho": "Bhojpuri",
     "br": "Breton",
     "bg": "Bulgarian",
@@ -39,10 +43,12 @@ lcode2lang = {
     "fo": "Faroese",
     "fi": "Finnish",
     "fr": "French",
+    "qfn": "Frisian_Dutch",
     "gl": "Galician",
     "de": "German",
     "got": "Gothic",
     "el": "Greek",
+    "gub": "Guajajara",
     "he": "Hebrew",
     "hi": "Hindi",
     "qhe": "Hindi_English",
@@ -52,9 +58,12 @@ lcode2lang = {
     "ga": "Irish",
     "it": "Italian",
     "ja": "Japanese",
+    "urb": "Kaapor",
+    "xnr": "Kangri",
     "krl": "Karelian",
     "kk": "Kazakh",
     "kfm": "Khunsari",
+    "quc": "Kiche",
     "koi": "Komi_Permyak",
     "kpv": "Komi_Zyrian",
     "ko": "Korean",
@@ -63,6 +72,9 @@ lcode2lang = {
     "olo": "Livvi",
     "la": "Latin",
     "lv": "Latvian",
+    "nds": "Low_Saxon",
+    "mpu": "Makurap",
+    "mal": "Malayalam",
     "mt": "Maltese",
     "gv": "Manx",
     "mr": "Marathi",
@@ -76,7 +88,7 @@ lcode2lang = {
     "nn": "Norwegian_Nynorsk",
     "cu": "Old_Church_Slavonic",
     "fro": "Old_French",
-    "orv": "Old_Russian",
+    "orv": "Old_East_Slavic",
     "otk": "Old_Turkish",
     "fa": "Persian",
     "pl": "Polish",
@@ -110,7 +122,9 @@ lcode2lang = {
     "vi": "Vietnamese",
     "wbp": "Warlpiri",
     "cy": "Welsh",
+    "hyw": "Western_Armenian",
     "wo": "Wolof",
+    "ess": "Yupik",
     "yo": "Yoruba",
 }
 
@@ -124,6 +138,9 @@ lcode2lang['zh'] = 'Simplified_Chinese'
 
 lang2lcode['Chinese'] = 'zh'
 
+# treebank names changed from Old Russian to Old East Slavic in 2.8
+lang2lcode['Old_Russian'] = 'orv'
+
 treebank_special_cases = {
     "UD_Chinese-GSDSimp": "zh_gsdsimp",
     "UD_Chinese-GSD": "zh-hant_gsd",
@@ -143,11 +160,17 @@ def treebank_to_short_name(treebank):
     if treebank.startswith('UD_'):
         treebank = treebank[3:]
     splits = treebank.split('-')
-    assert len(splits) == 2
+    assert len(splits) == 2, "Unable to process %s" % treebank
     lang, corpus = splits
 
-    lcode = lang2lcode[lang]
+    if lang in lang2lcode:
+        lcode = lang2lcode[lang]
+    elif lang in langlower2lcode:
+        lcode = langlower2lcode[lang]
+    elif lang in lcode2lang:
+        lcode = lang
+    else:
+        raise ValueError("Unable to find language code for %s" % lang)
 
     short = "{}_{}".format(lcode, corpus.lower())
     return short
-
